@@ -24,7 +24,6 @@
 
 #include <QTextDocument>
 #include <QTextCursor>
-#include <QMimeData>
 
 using namespace Milou;
 
@@ -32,11 +31,7 @@ PreviewPlugin::PreviewPlugin(QObject* parent)
     : QObject(parent)
     , m_context(nullptr)
 {
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
-    qmlRegisterAnonymousType<QMimeData>("org.kde.milou", 1);
-#else
-    qmlRegisterType<QMimeData>();
-#endif
+
 }
 
 PreviewPlugin::~PreviewPlugin()
